import { ResourceInfo } from './ResourceInfo';
/**
 * Pass this object to {@link AdminJS}'s `databases`
 * @example
 *  const adminJs = new AdminJS({
 *    databases: [database],
 *    // ...
 *  })
 */
export declare class DatabaseInfo {
    readonly databaseName: string;
    private resourceMap;
    constructor(databaseName: string, resourceMap: Map<string, ResourceInfo>);
    /**
     * Get ALL tables in database.
     *
     * @example
     * const adminJs = new AdminJS({
     *   databases: [database],
     *   resources: database.tables(),
     * });
     */
    tables(): ResourceInfo[];
    /**
     * Get specific table.
     * @example
     * const adminJs = new AdminJS({
     *   databases: [database],
     *   resources: [
     *    database.table('users'),
     *    database.table('posts'),
     *   ],
     * });
     */
    table(tableName: string): ResourceInfo;
}
