"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DatabaseInfo = void 0;
/**
 * Pass this object to {@link AdminJS}'s `databases`
 * @example
 *  const adminJs = new AdminJS({
 *    databases: [database],
 *    // ...
 *  })
 */
class DatabaseInfo {
    constructor(databaseName, resourceMap) {
        this.databaseName = databaseName;
        this.resourceMap = resourceMap;
    }
    /**
     * Get ALL tables in database.
     *
     * @example
     * const adminJs = new AdminJS({
     *   databases: [database],
     *   resources: database.tables(),
     * });
     */
    tables() {
        return Array.from(this.resourceMap.values());
    }
    /**
     * Get specific table.
     * @example
     * const adminJs = new AdminJS({
     *   databases: [database],
     *   resources: [
     *    database.table('users'),
     *    database.table('posts'),
     *   ],
     * });
     */
    table(tableName) {
        const r = this.resourceMap.get(tableName);
        if (!r) {
            throw new Error(`Table not exists: ${this.databaseName}.${tableName}`);
        }
        return r;
    }
}
exports.DatabaseInfo = DatabaseInfo;
//# sourceMappingURL=DatabaseInfo.js.map